Clazz.declarePackage("javajs.api");
Clazz.declareInterface(javajs.api, "JSONEncodable");
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
